@@ -241,7 +241,7 @@ def find_patterns(file):
     X = numpy.reshape(x_data, (n_patterns, seq_length, 1))
     X = X / float(vocab_len)
     y = np_utils.to_categorical(y_data)
-    outTuple = (X, y, chars)
+    outTuple = (x_data,X, y, chars)
     return outTuple
 
 
@@ -262,7 +262,7 @@ def set_model_params(X, y):
     return model
 
 
-def what_does_the_robot_say(model, chars,filename="model_weights_saved.hdf5"):
+def what_does_the_robot_say(x_data,model, chars,filename="model_weights_saved.hdf5"):
     model.load_weights(filename)
     model.compile(loss='categorical_crossentropy', optimizer='adam')
     num_to_char = dict((i, c) for i, c in enumerate(chars))
